@@ -16,6 +16,16 @@ has targets => (
   default => sub { [] },
 );
 
+sub build_defined_states {
+  my ($self) = @_;
+  [
+    $self => [ qw/
+      emitter_started
+      zmqsock_recv
+    / ],
+  ]
+}
+
 sub start {
   my ($self, @endpoints) = @_;
 
@@ -29,12 +39,14 @@ sub start {
 
 sub emitter_started {
   my ($kernel, $self) = @_[KERNEL, OBJECT];
-  $kernel->call( $self->zmq, subscribe => 'all' );
+
+  $kernel->call( $self->zmq => subscribe => qw/ 
+    recv
+  / );
 
   while (my $endpoint = shift @{ $self->targets }) {
     $self->add_connect( ZALIAS, $endpoint )
   }
-  1
 }
 
 after add_connect => sub {
@@ -53,9 +65,6 @@ sub request {
   $self->zmq->write( ZALIAS, $data )
 }
 
-sub zmqsock_created {}
-sub zmqsock_registered {}
-
 sub zmqsock_recv {
   my ($kernel, $self) = @_[KERNEL, OBJECT];
   my ($alias, $data)  = @_[ARG0, ARG1];
